pub struct Motion {Show 29 fields
pub instant_ms: u64,
pub quick_ms: u64,
pub menu_ms: u64,
pub dialog_ms: u64,
pub resize_ms: u64,
pub entrance_ms: u64,
pub spin_ms: u64,
pub slow_ms: u64,
pub stagger_step_ms: u64,
pub pulse_ms: u64,
pub shimmer_ms: u64,
pub toast_ms: u64,
pub linear: [f32; 4],
pub standard: [f32; 4],
pub ease_in: [f32; 4],
pub ease_out: [f32; 4],
pub ease_in_out: [f32; 4],
pub emphasized: [f32; 4],
pub overshoot: [f32; 4],
pub exit: [f32; 4],
pub settle: [f32; 4],
pub snappy: SpringTokens,
pub smooth: SpringTokens,
pub bouncy: SpringTokens,
pub grab: SpringTokens,
pub press_offset: f32,
pub hover_lift: f32,
pub flick_velocity: f32,
pub rubber_band_tension: f32,
}Fields
instant_ms: u64quick_ms: u64dialog_ms: u64resize_ms: u64entrance_ms: u64spin_ms: u64slow_ms: u64stagger_step_ms: u64The gap between one member of a staggered group and the next.
pulse_ms: u64shimmer_ms: u64toast_ms: u64linear: [f32; 4]standard: [f32; 4]ease_in: [f32; 4]ease_out: [f32; 4]ease_in_out: [f32; 4]emphasized: [f32; 4]overshoot: [f32; 4]exit: [f32; 4]settle: [f32; 4]snappy: SpringTokenssmooth: SpringTokensbouncy: SpringTokensgrab: SpringTokenspress_offset: f32How far a pressed control sinks, in pixels.
hover_lift: f32How far a hovered control rises, in pixels.
flick_velocity: f32The speed past which a released gesture is a flick, in pixels a second.
rubber_band_tension: f32How much of an overscroll is shown at the boundary.